typed.clj.checker.check-ns


check-nsclj

(check-ns ns-or-syms opt opts)
source

check-ns-infoclj

(check-ns-info ns-or-syms opt opts)

Same as check-ns, but returns a map of results from type checking the namespace.

Options

  • :type-provided? If true, use the expected type to check the form
  • :file-mapping If true, return map provides entry :file-mapping, a hash-map of (Map '{:line Int :column Int :file Str} Str).
Same as check-ns, but returns a map of results from type checking the
namespace.

Options
- :type-provided?  If true, use the expected type to check the form
- :file-mapping    If true, return map provides entry :file-mapping, a hash-map
                   of (Map '{:line Int :column Int :file Str} Str).
sourceraw docstring

default-check-configclj

(default-check-config)
source

cljdoc builds & hosts documentation for Clojure/Script libraries