typed.clj.checker.experimental.infer-vars


add-inferred-typeclj

(add-inferred-type checker nsym vsym t opts)

Add type t to the pool of inferred types of var vsym in namespace ns.

Add type t to the pool of inferred types of var vsym in namespace ns.
sourceraw docstring

infer-unannotated-varsclj

(infer-unannotated-vars nsym)
(infer-unannotated-vars checker nsym opts)

Return a vector of syntax that can be spliced into the given namespace, that annotates the inferred untyped variables.

Return a vector of syntax that can be spliced into the given namespace,
that annotates the inferred untyped variables.
sourceraw docstring

inferred-var-in-nsclj

(inferred-var-in-ns checker nsym vsym opts)
source

prepare-inferred-untyped-var-expressionclj

(prepare-inferred-untyped-var-expression checker nsym vsym opts)

Return an expression to eval in namespace nsym, which declares untyped var vsym as its inferred type.

Return an expression to eval in namespace nsym, which declares
untyped var vsym as its inferred type.
sourceraw docstring

using-alias-in-nsclj

(using-alias-in-ns nsym vsym opts)
source

cljdoc builds & hosts documentation for Clojure/Script libraries