typed.cljc.checker.check.const


check-constclj

(check-const expr expected opts)
(check-const {:keys [val] :as expr} expected quoted? opts)

Given a :const node and an expected type returns a new :const node annotated with its type.

quoted? should be true if this :const node is nested inside a :quote node, otherwise should be false

Given a :const node and an expected type returns a new :const
node annotated with its type.

quoted? should be true if this :const node is nested inside a
:quote node, otherwise should be false
sourceraw docstring

filter-for-valueclj

(filter-for-value val)
source

cljdoc builds & hosts documentation for Clojure/Script libraries