typed.cljc.checker.check.loop


check-loopclj

(check-loop expr
            expected
            {:typed.cljc.checker.check.recur-utils/keys [loop-bnd-anns]
             :as opts})
source

inline-annotationsclj

(inline-annotations expr opts)
source

parse-annotationclj

(parse-annotation tsyn {:keys [env] :as expr} opts)

Parse the raw type annotation tsyn in the context of expr

Parse the raw type annotation tsyn in the context of expr
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries