(check-const expr expected opts)(check-const {:keys [val] :as expr} expected quoted? opts)Given a :const node and an expected type returns a new :const node annotated with its type.
quoted? should be true if this :const node is nested inside a :quote node, otherwise should be false
Given a :const node and an expected type returns a new :const node annotated with its type. quoted? should be true if this :const node is nested inside a :quote node, otherwise should be false
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |