(check-loop expr
expected
{:typed.cljc.checker.check.recur-utils/keys [loop-bnd-anns]
:as opts})(parse-annotation tsyn {:keys [env] :as expr} opts)Parse the raw type annotation tsyn in the context of expr
Parse the raw type annotation tsyn in the context of expr
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |